==> common-1.7-RELEASE-sources.jar: io/afu/common/dto/CheckAlive.java <==
package io.afu.common.dto;

public class CheckAlive {
    public CheckAlive(){}
    public CheckAlive(String instantce_name, boolean alive, String checkTime) {
        super();
        this.instantce_name = instantce_name;
        this.alive = alive;
        this.checkTime = checkTime;
    }

    public CheckAlive(String instantce_name, boolean alive, String checkTime,String version,String profile) {
        super();
        this.instantce_name = instantce_name;
        this.alive = alive;
        this.checkTime = checkTime;
        this.version = version;
        this.profile = profile;
    }
    private static final long serialVersionUID = 633351988568966153L;

    /**
     * 应用实例名称
     */
    private String instantce_name;
    /**
     * 应用是否存活
     */
    private boolean alive;
    /**
     * 监测时间
     */
    private String checkTime;

    private String version;

    private String profile;

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getProfile() {
        return profile;
    }

    public void setProfile(String profile) {
        this.profile = profile;
    }

    public String getInstantce_name() {
        return instantce_name;
    }
    public void setInstantce_name(String instantce_name) {
        this.instantce_name = instantce_name;
    }
    public boolean getAlive() {
        return alive;
    }
    public void setAlive(boolean alive) {
        this.alive = alive;
    }
    public String getCheckTime() {
        return checkTime;
    }
    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }
    public static long getSerialversionuid() {
        return serialVersionUID;
    }

}

==> common-2.7-RELEASE-sources.jar: io/afu/common/dto/CheckAlive.java <==
package io.afu.common.dto;

public class CheckAlive {
    public CheckAlive(){}
    public CheckAlive(String instantce_name, boolean alive, String checkTime) {
        super();
        this.instantce_name = instantce_name;
        this.alive = alive;
        this.checkTime = checkTime;
    }

    public CheckAlive(String instantce_name, boolean alive, String checkTime,String version,String profile) {
        super();
        this.instantce_name = instantce_name;
        this.alive = alive;
        this.checkTime = checkTime;
        this.version = version;
        this.profile = profile;
    }
    private static final long serialVersionUID = 633351988568966153L;

    /**
     * 应用实例名称
     */
    private String instantce_name;
    /**
     * 应用是否存活
     */
    private boolean alive;
    /**
     * 监测时间
     */
    private String checkTime;

    /**
     * 监测版本
     */
    private String version;

    /**
     * 运行的Profile
     */
    private String profile;

    /**
     * 被卡住的版本
     */
    private String stack;


    public boolean isAlive() {
        return alive;
    }

    public String getStack() {
        return stack;
    }

    public void setStack(String stack) {
        this.stack = stack;
        this.alive = false;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getProfile() {
        return profile;
    }

    public void setProfile(String profile) {
        this.profile = profile;
    }

    public String getInstantce_name() {
        return instantce_name;
    }
    public void setInstantce_name(String instantce_name) {
        this.instantce_name = instantce_name;
    }
    public boolean getAlive() {
        return alive;
    }
    public void setAlive(boolean alive) {
        this.alive = alive;
    }
    public String getCheckTime() {
        return checkTime;
    }
    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }
    public static long getSerialversionuid() {
        return serialVersionUID;
    }

}
